@@ -46,7 +46,7 @@ class SambaUserSharePlugin : public KPropertiesDialogPlugin
 public:
     SambaUserSharePlugin(QObject *parent, const QList<QVariant> &args);
     virtual ~SambaUserSharePlugin();
-    virtual void applyChanges();
+    void applyChanges() override;
 
 private:
     QString m_url;
@@ -59,17 +59,21 @@ private:
     QLabel  *m_sambaStatusMessage;
     QProgressBar *m_installProgress;
     QPushButton *m_installSambaButton;
+#ifdef SAMBA_INSTALL
+    QWidget *m_justInstalledSambaWidgets;
+    QPushButton *m_restartButton;
+#endif // SAMBA_INSTALL
 
     void setupModel();
     void setupViews();
-    QStringList getUsersList();
-    QString getNewShareName();
+    QString getNewShareName() const;
     void load();
     void toggleShareStatus(bool checked);
     void checkShareName(const QString &name);
 #ifdef SAMBA_INSTALL
     void installSamba();
     void packageFinished(PackageKit::Transaction::Exit status, uint runtime);
+    void reboot();
 #endif // SAMBA_INSTALL
 
 
